@@ -2,7 +2,7 @@
  *                          lspclient.cpp  -  description
  *                             -------------------
  *    begin                : Wed Jan 20 2021
- *    copyright            : (C) 2002-2023 by Andre Simon
+ *    copyright            : (C) 2002-2026 by Andre Simon
  *    email                : a.simon@mailbox.org
  ***************************************************************************/
 
@@ -194,8 +194,8 @@ namespace highlight
 
         #else
 
-        pipe(inpipefd);
-        pipe(outpipefd);
+        std::ignore = pipe(inpipefd);
+        std::ignore = pipe(outpipefd);
 
         pid = fork();
 
